@@ -250,7 +250,7 @@ init_remailer (void)
 	    {
 	      /* If that fails, create a new list with 'pgp -kv'. */
 	      repgplist = fopen ("type1.list", "w+");
-	      run_cmd (PGP, "-kv", REPGP_KEYS, NULL, repgplist, stderr);
+	      run_cmd (PGP, "-kv", NULL, NULL, repgplist, stderr);
 	      unlink ("type1.list");
 	    }
 	}
