@@ -37,7 +37,7 @@ run_cmd (const char *command, const char *option, const char *arg,
   FILE *passfile;
   struct flock lock;
   int pipefd[2], lockfd, status;
-  char line[BUFSIZ];
+  char line[BUFSIZ], pubring[BUFSIZ];
 
   /* PGP needs exclusive access to randseed.bin.  */
   if (!strcmp (command, PGP))
@@ -115,6 +115,7 @@ run_cmd (const char *command, const char *option, const char *arg,
 	{
 	  setenv ("PGPPATH", PGP_DIR, 1);
 	  setenv ("PGPPASSFD", line, 1);
+	  sprintf (pubring, "+pubring=%s", REPGP_KEYS);
 	}
       close (pipefd[0]);
 
@@ -126,19 +127,19 @@ run_cmd (const char *command, const char *option, const char *arg,
 	  else if (!strcmp (option, "-e"))
 	    /* RSA-encrypt infile to outfile.  */
 	    execl (command, "pgp", "+batchmode", "+verbose=0", "+armorlines=0",
-		   "-fat", option, arg, NULL);
+		   pubring, "-fat", option, arg, NULL);
 	  else if (!strcmp (option, "-c"))
 	    /* IDEA-encrypt infile to outfile.  */
 	    execl (command, "pgp", "+batchmode", "+verbose=0", "+armorlines=0",
 		   "-fat", option, NULL);
 	  else if (!strcmp (option, "-a"))
-	    /* ASCII-armore infile to outfile.  */
+	    /* ASCII-armor infile to outfile.  */
 	    execl (command, "pgp", "+batchmode", "+verbose=0", "+armorlines=0",
 		   "-f", option, NULL);
 	  else if (!strcmp (option, "-kv"))
 	    /* Look for public key in keyring */
-	    execl (command, "pgp", "+batchmode", "+verbose=0", option, arg,
-		   NULL);
+	    execl (command, "pgp", "+batchmode", "+verbose=0", pubring, option,
+		   arg, NULL);
 	}
       else if (!strcmp (command, GPG))
 	{
